@@ -15,12 +15,12 @@ __keep_imports = [
     ogdf_python.jupyter,
 ]
 
-__version__ = "0.2.2"
+__version__ = "0.3.1"
 __all__ = ogdf_python.loader.__all__ + ogdf_python.utils.__all__ + ogdf_python.info.__all__
 
 try:
-    from ogdf_python.matplotlib import *
-
-    __all__ += ogdf_python.matplotlib.__all__
+    import matplotlib
 except ImportError:
     pass
+else:
+    from ogdf_python.matplotlib import *
